.. _cmd_debops-init:

The :command:`debops-init` command
==================================

Creates a project for you at the path you specify. After running this script
you should check out :command:`ansible/inventory/hosts` relative to your project path.

Example commands:

.. code:: shell

    debops-init ~/myproject
